# Copyright 2004 James Bunton <james@delx.cjb.net>
# Licensed for distribution under the GPL version 2, check COPYING for details

class LegacyConnection:
	""" A base class that must have all functions reimplemented by legacy protocols to translate
	from Jabber to that legacy protocol. Any incoming events from the legacy system must be
	translated by calling the appropriate functions in the Session, JabberConnection or PyTransport classes."""
	def __init__(self, session):
		pass
	
	def removeMe(self):
		""" Called by PyTransport when the user's session is ending.
		Must cleanly delete this object. Including sending an offline presence packet
		for any contacts that may be on the user's list """
		pass
	
	def sendMessage(self, dest, body):
		""" Called whenever PyTransport wants to send a message to a remote user """
		pass
	
	def setStatus(self, show, friendly):
		""" Called whenever PyTransport needs to change the status on the legacy service 
		'show' is a Jabber status description, and friendly is a friendly name for the contact """
		pass
	
	def newResourceOnline(self, resource):
		""" Called by PyTransport when a new resource comes online """
		pass
	
	def jabberSubscriptionReceived(self, to, subtype):
		""" Called by PyTransport whenever a Jabber subscription packet is received """
		pass


